#ifndef ONEEYEMAP_H
#define ONEEYEMAP_H

#include <QWidget>
#include <memory>
#include <QTimer>

#include "spdlog/spdlog.h"

#include "OscData.h"
#include "GlobalInfo.h"

namespace Ui {
class OneEyeMap;
}

class OneEyeMap : public QWidget
{
    Q_OBJECT

public:
    explicit OneEyeMap(QWidget *parent = nullptr);
    ~OneEyeMap();

signals:
    void signal_update();

private slots:
    void do_update();

protected:
    void paintEvent(QPaintEvent *event) override;
    /* 缩放事件 */
    void resizeEvent(QResizeEvent *event) override;

private:
    /* 绘制刻度值区域 */
    void drawScaleValue(QPainter &painter);
    /* 绘制刻度 */
    void drawScale(QPainter &painter);
    /* 绘制眼图区域 */
    void drawEyeMap(QPainter &painter);

    /* 获取一个格子的电压值 */
    inline QString getVScaleValue(int index);
    /* 获取一个时间值 */
    inline QString getTimeValue(int index);
    

private:
    Ui::OneEyeMap *ui;
    std::shared_ptr<spdlog::logger> m_logger = nullptr;
    QTimer m_timer;

    QRect m_rectScaleValue;             /* 刻度值区域 */
    QRect m_rectEyeMap;                 /* 眼图区域 */
    int m_leftMargin = 0;               /* 眼图距离刻度区域的左边距 */
    int m_topMargin = 0;                /* 眼图距离刻度区域的上边距 */
    int m_rightMargin = 0;              /* 眼图距离刻度区域的右边距 */
    int m_bottomMargin = 0;             /* 眼图距离刻度区域的下边距 */

    int m_hScaleNum = 0;                /* 水平刻度 */
    int m_vScaleNum = 0;                /* 垂直刻度 */

    OscChannelRange m_cRange = OscChannelRange::CR_2V5;    /* 通道输入档位 */
    OscTimeGridValue m_tGridValue = OscTimeGridValue::TGV_200NS;    /* 时间刻度值 */
};

#endif // ONEEYEMAP_H